@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 """
-Copyright (c) 2008-2023, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -16,7 +16,7 @@ copyright notice, this list of conditions and the following
 disclaimer in the documentation and/or other materials provided
 with the distribution.
 
-3. Neither the name of Jesus Cea Avion nor the names of its
+3. Neither the name of Jesús Cea Avión nor the names of its
 contributors may be used to endorse or promote products derived
 from this software without specific prior written permission.
 
@@ -263,37 +263,6 @@ if os.name == 'posix':
         libname = []
     utils = []
 
-    # Test if the old bsddb is built-in
-    static = 0
-    try:
-        # Possibly already imported in the "warning" section (python 2.7)
-        import bsddb
-        if str(bsddb).find('built-in') >= 0:
-            static = 1
-    except ImportError:
-        pass
-
-    # On Un*x, double check that no other built-in module pulls libdb in as a
-    # side-effect. TBD: how/what to do on other platforms?
-    fp = os.popen('ldd %s 2>&1' % sys.executable)
-    results = fp.read()
-    status = fp.close()
-    if not status and results.find('libdb.') >= 0:
-        static = 1
-
-    if static:
-        print("""\
-\aWARNING:
-\tIt appears that the old bsddb module is staticly linked in the
-\tPython executable. This will cause various random problems for
-\tbsddb, up to and including segfaults. Please rebuild your
-\tPython either with bsddb disabled, or with it built as a shared
-\tdynamic extension. Watch out for other modules (e.g. dbm) that create
-\tdependencies in the python executable to libdb as a side effect.""")
-        st = input("Build anyway? (yes/[no]) ")
-        if st != "yes":
-            sys.exit(1)
-
     # read db.h to figure out what version of Oracle Berkeley DB this is
     ver = None
     with open(os.path.join(incdir, 'db.h'), 'r') as f :
@@ -320,65 +289,16 @@ if os.name == 'posix':
     print('Detected Oracle Berkeley DB version %d.%d from db.h' %db_ver)
 
 elif os.name == 'nt':
+    print()
+    print('MS Windows is unsupported. I you need it, please let me know!')
+    print()
+    sys.exit(1)
 
-    # The default build of Oracle Berkeley DB for windows just leaves
-    # everything in the build dirs in the db source tree. That means
-    # that we either have to hunt around to find it, (which would be
-    # even more difficult than the mess above for Unix...) or we make
-    # the builder specify everything here. Compounding the problem is
-    # version numbers in default path names, and different library
-    # names for debug/release or dll/static.
-    #
-    # So to make things easier, I'm just going to expect that the DB stuff
-    # has been moved to the ./db directory. There's an updatedb.bat file to
-    # help.
-    #
-    # You'll need to edit the project file that comes with Oracle Berkeley DB
-    # so it uses "Multithreaded DLL" and "Debug Multithreaded DLL"  (/MD and
-    # /MDd) settings as appropriate to build .lib file (the db_static
-    # project).
-
-    incdir = 'db/include'
-    libdir = 'db/lib'
-
-    # read db.h to figure out what version of Oracle Berkeley DB this is
-    ver = None
-    with open(os.path.join(incdir, 'db.h'), 'r') as f :
-        db_h_lines = f.readlines()
-    db_ver_re = re.compile(
-        r'^#define\s+DB_VERSION_STRING\s.*Berkeley DB (\d+\.\d+).*')
-    for line in db_h_lines:
-        match = db_ver_re.match(line)
-        if not match:
-            continue
-        fullverstr = match.group(1)
-        ver = fullverstr.split('.')
-        db_ver = (int(ver[0]), int(ver[1]))
-    if db_ver not in db_ver_list:
-        raise AssertionError(
-                'berkeleydb untested with this Oracle Berkeley DB '
-                'version %d.%d' %db_ver)
-    print('Detected Oracle Berkeley DB version %d.%d from db.h' %db_ver)
-
-    if debug:
-        libname = ['libdb%ssd' % ver]     # Debug, static
-    else:
-        libname = ['libdb%ss' % ver]      # Release, static
-    utils = [("berkeleydb/utils",
-              ["db/bin/db_archive.exe",
-               "db/bin/db_checkpoint.exe",
-               "db/bin/db_deadlock.exe",
-               "db/bin/db_dump.exe",
-               "db/bin/db_load.exe",
-               "db/bin/db_printlog.exe",
-               "db/bin/db_recover.exe",
-               "db/bin/db_stat.exe",
-               "db/bin/db_upgrade.exe",
-               "db/bin/db_verify.exe",
-               "db/bin/libdb%s.dll" % ver,
-               ]),
-             ("berkeleydb/test", glob.glob("test/*.py"))
-             ]
+else:
+    print()
+    print(f'"{os.name}" is unsupported. I you need it, please let me know!')
+    print()
+    sys.exit(1)
 
 if (db_ver >= (6, 0)) and \
   ("YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION" not in os.environ) :
@@ -475,7 +395,7 @@ you can use legacy `bsddb3 <https://pypi.org/project/bsddb3/>`__ library.
 `Mailing List <https://mailman.jcea.es/listinfo/pybsddb>`__ --
 `Donation <https://docs.jcea.es/berkeleydb/latest/donate.html>`__
 """,
-      author = 'Jesus Cea, Robin Dunn, Gregory P. Smith, Andrew Kuchling, Barry Warsaw',
+      author = 'Jesús Cea Avión, Robin Dunn, Gregory P. Smith, Andrew Kuchling, Barry Warsaw',
       author_email = 'pybsddb@jcea.es',
       url = 'https://www.jcea.es/programacion/pybsddb.htm',
       license = "3-clause BSD License",
@@ -490,6 +410,7 @@ you can use legacy `bsddb3 <https://pypi.org/project/bsddb3/>`__ library.
                                runtime_library_dirs = [ libdir ],
                                libraries = libname,
                                extra_link_args = lflags_arg,
+                               py_limited_api = True,
                                )],
       headers = ['src/Module/berkeleydb.h'],
       data_files = utils,
@@ -500,7 +421,7 @@ you can use legacy `bsddb3 <https://pypi.org/project/bsddb3/>`__ library.
                     'Intended Audience :: Information Technology',
                     'Natural Language :: English',
                     'Natural Language :: Spanish',
-                    'Operating System :: OS Independent',
+                    'Operating System :: Unix',
                     'Programming Language :: Python',
                     'Topic :: Database',
                     'Topic :: Software Development',
