@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 """
-Copyright (c) 2008-2023, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -16,7 +16,7 @@ copyright notice, this list of conditions and the following
 disclaimer in the documentation and/or other materials provided
 with the distribution.
 
-3. Neither the name of Jesus Cea Avion nor the names of its
+3. Neither the name of Jesús Cea Avión nor the names of its
 contributors may be used to endorse or promote products derived
 from this software without specific prior written permission.
 
@@ -54,7 +54,7 @@ import os
 os.environ['YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION'] = ''
 
 def do_matrix_check() :
-  python_versions = ('3.8', '3.9', '3.10', '3.11', '3.12')
+  python_versions = ('3.8', '3.9', '3.10', '3.11', '3.12', '3.13')
 
   berkeleydb_versions=('4.8', '5.3', '6.2', '18.1')
 
