@@ -140,13 +140,19 @@ from unittest import TextTestResult
 from sysconfig import get_platform
 
 import setuptools
+import packaging.version
 
 # We need to be able to test BDB releases, even if the license is incompatible
 os.environ['YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION'] = ''
 
 
 PROGRAM = sys.argv[0]
-PLAT_SPEC = f'{get_platform()}-{sys.implementation.cache_tag}'
+min_version = packaging.version.parse('62.1.0')
+if packaging.version.parse(setuptools.__version__) >= min_version:
+    PLAT_SPEC = f'{get_platform()}-{sys.implementation.cache_tag}'
+else:
+    version = sys.version_info
+    PLAT_SPEC = f'{get_platform()}-{version.major}.{version.minor}'
 
 # This hack copied from distutils.command.build.  Too bad distutils
 # doesn't export its build/ directory naming scheme as a library function.
