@@ -1,5 +1,5 @@
 """
-Copyright (c) 2008-2023, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2024, Jesús Cea Avión <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -14,7 +14,7 @@ are met:
     disclaimer in the documentation and/or other materials provided
     with the distribution.
 
-    3. Neither the name of Jesus Cea Avion nor the names of its
+    3. Neither the name of Jesús Cea Avión nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.
 
@@ -79,14 +79,16 @@ def print_versions():
 
     # Workaround for allowing generating an EGGs as a ZIP files.
     suffix="__"
-    print('py module:           %s' % getattr(berkeleydb, "__file"+suffix))
-    print('extension module:    %s' % getattr(berkeleydb._db, "__file"+suffix))
-
-    print('Test working dir:    %s' % get_test_path_prefix())
-    print('python version:      %s %s' % \
+    print(f'py module:          {getattr(berkeleydb, "__file"+suffix)}')
+    print(f'extension module:   {getattr(berkeleydb._db, "__file"+suffix)}')
+    print(f'Test working dir:   {get_test_path_prefix()}')
+    print('python version:     %s %s' % \
             (sys.version.replace("\r", "").replace("\n", ""), \
             platform.architecture()[0]))
-    print('My pid:              %s' % os.getpid())
+    stable_abi, compiled_under = (hex(i) for i in berkeleydb.py_limited_api())
+    print(f'Stable ABI:         {stable_abi}')
+    print(f'Compiled under:     {compiled_under}')
+    print(f'My pid:             {os.getpid()}')
     print('-=' * 38)
 
 
